@@ -38,7 +38,7 @@ class Trainer(object):
         self._nc: Union[_network.NetworkC, None] = None
         self._lfc: Union[_network.LossFunctionC, None] = None
         self._oc: Union[_network.OptimizerC, None] = None
-        self._config: _cfg.Config = _cfg.ConfigContainer().CURRENT
+        self._config: _cfg.Config = _cfg.CONFIG().CURRENT
         self._dataloader: _dl.Dataloader = dataloader
         self._epoch: int = 0
         self.losses: list[float] = []
@@ -62,7 +62,7 @@ class Trainer(object):
         return self._epoch
 
     def set_network(self, nc: _network.NetworkC):
-        if self._config.get_predefined("gpu_acceleration", True):
+        if self._config.get_predefined("gpu_acceleration"):
             nc = nc.gpu()
         self._nc = nc
 
@@ -70,7 +70,7 @@ class Trainer(object):
         return self._nc
 
     def set_loss_function(self, lfc: _network.LossFunctionC):
-        if self._config.get_predefined("gpu_acceleration", True):
+        if self._config.get_predefined("gpu_acceleration"):
             lfc = lfc.gpu()
         self._lfc = lfc
 
@@ -78,7 +78,7 @@ class Trainer(object):
         return self._lfc
 
     def set_optimizer(self, oc: _network.OptimizerC):
-        if self._config.get_predefined("gpu_acceleration", True):
+        if self._config.get_predefined("gpu_acceleration"):
             oc = oc.gpu()
         self._oc = oc
 
@@ -99,7 +99,7 @@ class Trainer(object):
         for data in self._dataloader:
             if local_epoch >= num_batches:
                 break
-            if self._config.get_predefined("gpu_acceleration", True):
+            if self._config.get_predefined("gpu_acceleration"):
                 data = data.gpu()
             o, loss = self._train_one_batch(self._epoch, self._nc.get(), self._lfc.get(), self._oc.get(), data)
             self.losses.append(loss)
@@ -121,17 +121,46 @@ class Trainer(object):
         :return: {network output, loss}
         """
         raise NotImplementedError
-    
 
-class TrainerUtils(object):
+
+class TrainerDataUtils(object):
     @staticmethod
-    def limit(trainer: Trainer, n: float) -> Trainer:
+    def vibration(losses: list) -> bool:
+        if len(losses) == 2:
+            return losses[1] > losses[0]
+        if all(x > y for x, y in zip(losses, losses[1:])):
+            return False
+        new_losses = []
+        for i in range(0, len(losses), 2):
+            new_losses.append(0.5 * sum(losses[i: i + 2]))
+        return TrainerDataUtils.vibration(new_losses)
+
+    @staticmethod
+    def analyse(trainer: Trainer) -> dict:
+        length = len(trainer.losses)
+        if length < 20:
+            raise RuntimeError("Samples not enough to analyse.")
+        min_loss = min(trainer.losses)
+        max_loss = max(trainer.losses)
+        average_loss = sum(trainer.losses) / length
+        vibration = TrainerDataUtils.vibration(trainer.losses[:round(length * 0.1)])
+        print(f"Loss: {round(min_loss, 2)}~{round(max_loss, 2)}({round(average_loss, 2)} on average)\n"
+              f"Vibration: {vibration}")
+        return {
+            "min_loss": min_loss,
+            "max_loss": max_loss,
+            "average_loss": average_loss,
+            "vibration": vibration,
+        }
+
+    @staticmethod
+    def limit_losses(trainer: Trainer, n: float) -> Trainer:
         trainer = _copy(trainer)
         trainer.losses = [i for i in trainer.losses if i <= n]
         return trainer
 
     @staticmethod
-    def scale(trainer: Trainer, ratio: float) -> Trainer:
+    def scale_losses(trainer: Trainer, ratio: float) -> Trainer:
         """
         Uniformly remove a certain proportion of the loss data.
         :param trainer: the object to be operated
@@ -156,12 +185,11 @@ class TrainerUtils(object):
         return trainer
 
     @staticmethod
-    def remove(trainer: Trainer, n: int) -> Trainer:
+    def remove_losses(trainer: Trainer, n: int) -> Trainer:
         """
         Uniformly remove a certain amount of the loss data.
         :param trainer: the object to be operated
         :param n: the amount
         :return: another edited object
         """
-        return TrainerUtils.scale(trainer, n / len(trainer.losses))
-
+        return TrainerDataUtils.scale_losses(trainer, n / len(trainer.losses))
